.. sidebar:: Key Contributors
   :subtitle: `pyGPCCA graph`_ | ☀ = maintainer

   * `Bernhard Reuter`_: lead developer ☀
   * `Michal Klein`_: developer, diverse contributions
   * `Marius Lange`_: developer, diverse contributions

.. _pyGPCCA graph: https://github.com/msmdev/pyGPCCA/graphs/contributors
.. _Bernhard Reuter: https://github.com/msmdev
.. _Michal Klein: https://github.com/michalk8
.. _Marius Lange: https://github.com/Marius1311
